@@ -79,7 +79,7 @@ plugin_run(env)
   while(ports[i])
   {
    int pport = htons(ports[i]);
-   unsigned char * port = (char*)&(pport);
+   unsigned char * port = (unsigned char*)&(pport);
    sprintf(command, "PORT %d,%d,%d,%d,%d,%d\n", ip[0], ip[1], ip[2], ip[3],
    						port[0], port[1]);
    send(soc, command, strlen(command), 0);
