@@ -93,7 +93,7 @@ PlugExport int plugin_run(struct arglist * env)
  if(!plug_get_key(env, "ftp/anonymous"))return(0);
  if(host_get_port_state(env, port)<=0)return(0);
  if((soc = open_sock_tcp(env, port))<0)return(0);
- if(ftp_log_in(soc, "anonymous", "joe@"))return(0);
+ if(ftp_log_in(soc, "anonymous", "nessus@nessus.org"))return(0);
  dirs->name = emalloc(2);
  dirs->name[0]='/';
  dirs->writeable=0;
@@ -157,7 +157,7 @@ void ftp_explore_dir(int soc, struct ftp_dirs * dirs, int write)
  if(connect(data_soc, (struct sockaddr *)&addr, sizeof(struct sockaddr_in)))
  	return;
  command = emalloc(strlen(dirs->name)+20);
- sprintf(command, "LIST %s\n", dirs->name);
+ sprintf(command, "LIST %s\r\n", dirs->name);
  send(soc, command, strlen(command), 0);
  buf = emalloc(255);
  recv_line(soc, buf, 255);
@@ -201,15 +201,15 @@ void ftp_explore_dir(int soc, struct ftp_dirs * dirs, int write)
        {
        command = emalloc(255);
        is_writeable = 0;
-       sprintf(command, "STOR %s/.nessuscheck\n", file_name);
+       sprintf(command, "STOR %s/nessuscheck\r\n", file_name);
        send(soc, command, strlen(command), 0);
        bzero(command, 255);
        recv(soc, command, 254, 0);
        command[3] = 0;
        code = atoi(command);
-       if(code == 425){
+       if((code == 425)||(code == 150)){
        	 is_writeable = 1;
-	 sprintf(command, "DELE %s/.nessuscheck\n", file_name);
+	 sprintf(command, "DELE %s/nessuscheck\r\n", file_name);
          send(soc, command, strlen(command), 0);
          bzero(command, 255);
          recv(soc, command, 254, 0);
