@@ -70,7 +70,7 @@ PlugExport int plugin_init(struct arglist * desc)
 
 PlugExport int plugin_run(struct arglist * env)
 {
-  short *ports;
+  unsigned short *ports;
   struct arglist * globals = arg_get_value(env, "globals");
   struct arglist * hostinfos = arg_get_value(env, "HOSTNAME");
   char * port_range = arg_get_value(env, "port_range");
