@@ -62,12 +62,12 @@ unsigned long adr;
 
 
 
-char numer_one[0x10]={
+unsigned char numer_one[0x10]={
 0x00,0x01,0x00,0x00,0x00,0x01,0x00,0x00,
 0x00,0x00,0x00,0x24,0x00,0x00,0x00,0x00
 };
 
-char numer_two[0x24]={
+unsigned char numer_two[0x24]={
 0x21,0x03,0x00,0x43,0x00,0x0a,0x00,0x0a,
 0x01,0x01,0x3b,0x01,0x6e,0x00,0x00,0x80,
 0x43,0x01,0x01,0x18,0x0b,0x01,0x01,0x3b,
@@ -77,12 +77,12 @@ char numer_two[0x24]={
 
 
 #ifdef WORDS_BIGENDIAN
-char fake_adrs[0x10]={
+unsigned char fake_adrs[0x10]={
 0x00,0x02,0x14,0x0f,0xff,0xff,0xff,0xff,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00
 };
 #else
-char fake_adrs[0x10]={
+unsigned char fake_adrs[0x10]={
 0x02,0x00,0x14,0x0f,0xff,0xff,0xff,0xff,
 0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00
 };
@@ -93,9 +93,9 @@ char *get_sysinfo(){
     fd_set rd;
     struct timeval tv;
     
-    iov[0].iov_base=numer_one;
+    iov[0].iov_base=(char*)numer_one;
     iov[0].iov_len=0x10;
-    iov[1].iov_base=numer_two;
+    iov[1].iov_base=(char*)numer_two;
     iov[1].iov_len=0x24;
 #if 1 /* PATCH (see below) */   
     memset (&msg, 0, sizeof msg);
