@@ -71,6 +71,8 @@ u_short cksum(u_short *buf, int nwords)
 PlugExport int plugin_init(struct arglist *desc);
 PlugExport int plugin_init(struct arglist *desc)
 {
+  plug_set_id(desc, 10338);
+
   plug_set_name(desc, NAME, NULL);
   plug_set_description(desc, FR_DESC, "francais");
   plug_set_description(desc, EN_DESC, NULL);
@@ -151,7 +153,7 @@ PlugExport int plugin_run(struct arglist * env)
       tcp->th_sport = htons(fromport);
       tcp->th_seq   = htonl(32089744);
       tcp->th_ack   = htonl(0);
-#ifdef HAVE_TCPHDR_TH_OFF
+#ifndef HAVE_TCPHDR_X2_TH_OFF
       tcp->th_off   = sizeof(struct tcphdr)/4;
 #else
       tcp->th_x2_off = sizeof(struct tcphdr)/4 << 4;
